@@ -37,7 +37,8 @@ class NumberFormatting:
         if v >= 1000:
             value_mag = math.log10(v)
 
-            suffix_index = min(len(SI_suffix) - 1, max(0, math.floor(value_mag / 3) - 1))
+            suffix_index = min(len(SI_suffix) - 1,
+                               max(0, math.floor(value_mag / 3) - 1))
 
             value = v / pow(10, (suffix_index + 1) * 3)
             suffix = SI_suffix[suffix_index]
@@ -65,7 +66,8 @@ class NumberFormatting:
         if v >= 1024:
             value_mag = math.log(v, 2)
 
-            suffix_index = min(len(SI_suffix) - 1, max(0, math.floor(value_mag / 10) - 1))
+            suffix_index = min(len(SI_suffix) - 1,
+                               max(0, math.floor(value_mag / 10) - 1))
 
             value = v / pow(2, (suffix_index + 1) * 10)
             suffix = SI_suffix[suffix_index] + "i"
@@ -143,12 +145,13 @@ class NumberFormatting:
             return "-" + NumberFormatting.formatUnitsPerIntervalDynamic(abs(units), seconds, unit)
 
         if seconds <= 0:
-            raise InvalidDurationException(str("{:s} is not a valid, positive duration").format(str(seconds)))
+            raise InvalidDurationException(
+                str("{:s} is not a valid, positive duration").format(str(seconds)))
 
         units_per_second = units / seconds
         units_per_millisecond = units_per_second / 1000.0
         units_per_microsecond = units_per_second / 1000000.0
-        units_per_millenium = units_per_second * 1000.0 * 365.0 * 86400.0
+        units_per_millennium = units_per_second * 1000.0 * 365.0 * 86400.0
         units_per_century = units_per_second * 100.0 * 365.0 * 86400.0
         units_per_year = units_per_second * 365.0 * 86400.0
         units_per_week = units_per_second * 7.0 * 86400.0
@@ -157,7 +160,7 @@ class NumberFormatting:
         units_per_minute = units_per_second * 60.0
 
         if units_per_century < 1.0:
-            return str("{:.2f}{:s}/{:s}").format(units_per_millenium, unit, "millenium")
+            return str("{:.2f}{:s}/{:s}").format(units_per_millennium, unit, "millennium")
         elif units_per_year < 1.0:
             return str("{:.2f}{:s}/{:s}").format(units_per_century, unit, "century")
         elif units_per_week < 1.0:
