@@ -1,6 +1,6 @@
 var dir_56c4ad8400746b2716421bb39ef4a0b1 =
 [
-    [ "__init__.py", "pycommons_2serializers_2____init_____8py.html", null ],
+    [ "__init__.py", "caellion_2pycommons_2serializers_2____init_____8py.html", null ],
     [ "datetime_serializer.py", "datetime__serializer_8py.html", [
       [ "DateTimeIsoTimeSerializer", "classcaellion_1_1pycommons_1_1serializers_1_1datetime__serializer_1_1_date_time_iso_time_serializer.html", null ],
       [ "DateTimeUnixMillisSerializer", "classcaellion_1_1pycommons_1_1serializers_1_1datetime__serializer_1_1_date_time_unix_millis_serializer.html", null ],
