@@ -1,7 +1,9 @@
 var namespacecaellion_1_1pycommons =
 [
     [ "codeanalysis", "namespacecaellion_1_1pycommons_1_1codeanalysis.html", "namespacecaellion_1_1pycommons_1_1codeanalysis" ],
+    [ "encoding", "namespacecaellion_1_1pycommons_1_1encoding.html", "namespacecaellion_1_1pycommons_1_1encoding" ],
     [ "encryption", "namespacecaellion_1_1pycommons_1_1encryption.html", "namespacecaellion_1_1pycommons_1_1encryption" ],
+    [ "hashing", "namespacecaellion_1_1pycommons_1_1hashing.html", "namespacecaellion_1_1pycommons_1_1hashing" ],
     [ "serializers", "namespacecaellion_1_1pycommons_1_1serializers.html", "namespacecaellion_1_1pycommons_1_1serializers" ],
     [ "stringutil", "namespacecaellion_1_1pycommons_1_1stringutil.html", "namespacecaellion_1_1pycommons_1_1stringutil" ]
 ];
\ No newline at end of file
